#!/usr/bin/env node
"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const commander_1 = require("commander");
const minimatch_1 = require("minimatch");
const fs_1 = require("fs");
const path_1 = __importDefault(require("path"));
const kleur_1 = __importDefault(require("kleur"));
const browser_compatibility_checker_1 = require("./browser-compatibility-checker");
const compatIssues = require("./browser-compatibility-checker/compat-issues.json");
const DEFAULT_BROWSERS = [
    "chrome",
    "edge",
    "firefox",
    "opera",
    "safari",
    "ie",
    "chrome_android",
    "firefox_android",
    "opera_android",
    "safari_ios",
    "samsunginternet_android",
    "webview_android",
];
commander_1.program
    .description("Scan files for browser compatibility issues")
    .option("-f, --folder <folder>", "Folder to scan")
    .option("-b, --browsers [browsers]", "Comma seperated list of browsers to check", DEFAULT_BROWSERS)
    .option("-i, --ignore [ignore]", "Comma seperated list of glob paths to ignore", ["**/node_modules/**", "**/.**/**", "**/**.test.**", "**/**.spec.**"]);
commander_1.program.parse(process.argv);
const { folder, browsers, ignore } = commander_1.program.opts();
if (!folder) {
    console.error(kleur_1.default.red("No folder path provided."));
    process.exit(1);
}
const browsersList = (0, browser_compatibility_checker_1.getBrowsersList)(folder);
const browsersArg = typeof browsers === "string" ? browsers.split(",") : browsers;
const browsersToCheck = browsersList && browsersList.length > 0 && browsersArg == DEFAULT_BROWSERS
    ? browsersList
    : browsersArg;
const pathsToIgnore = typeof ignore === "string" ? ignore.split(",") : ignore;
const files = (0, fs_1.readdirSync)(folder, { recursive: true, encoding: "utf8" });
console.log(`Scanning: ${folder} (${files.length} files)`);
let hasIssue = false;
for (const [fileRegex, issues] of Object.entries(compatIssues)) {
    for (const file of files) {
        const filePath = path_1.default.join(folder, file);
        if ((0, minimatch_1.minimatch)(filePath, fileRegex, { nocase: true })) {
            if (pathsToIgnore.some((folder) => (0, minimatch_1.minimatch)(filePath, folder, { nocase: true }))) {
                continue;
            }
            const text = (0, fs_1.readFileSync)(filePath, "utf8");
            const matches = (0, browser_compatibility_checker_1.findIssues)(text, issues, browsersToCheck, false);
            if (matches.length > 0) {
                hasIssue = true;
                console.error(kleur_1.default.red(`Issues found with ${filePath}:`));
                for (const { message } of matches) {
                    console.log(`  - ${message}`);
                }
            }
            else {
                console.log(kleur_1.default.green(filePath));
            }
        }
    }
}
if (hasIssue) {
    console.log("Issues detected. Address these issues or change --browsers to ingore irrelavant browser issues");
    process.exit(1);
}
else {
    console.log("No issues detected!");
}
//# sourceMappingURL=cli.js.map